#
# spec file for package octave-forge-symbolic
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  symbolic
Name:           octave-forge-%{octpkg}
Version:        3.0.1
Release:        1.2
Summary:        Octave Symbolic Package using SymPy
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/%{octpkg}/
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  octave-devel
BuildRequires:  python3-sympy >= 1.4
Requires:       octave-cli >= 5.1
Requires:       python3-sympy >= 1.4

%description
Adds symbolic calculation features to GNU Octave.
These include common Computer Algebra System tools such as algebraic
operations, calculus, equation solving, Fourier and Laplace transforms,
variable precision arithmetic and and other features. Compatibility
with other symbolic toolboxes is a goal.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}

%changelog
* Thu Sep 15 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.0.1:
  * New `@double` numerical functions; these are wrappers around SymPy,
    so they are slower than native floating-point implementations.
  - adjoint
  * Misc bug fixes and improvements in error handling.
  * `.oct-config` files indicate source is UTF-8 encoded and should improve
    any locale or encoding problems on Octave 7 and above.
  * Fixes some errors when Python is running in Cygwin-like environment.
    But there could still be errors in other places (issue #1182).
* Fri Jul  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.0:
  * New symbolic commands: cumprod cumsum ztrans.
  * `dsolve` output prefers expressions (right-hand sides) rather
    than equations.  Also uses structs for systems.  This brings
    it closer to `solve` and more compatible with other symbolic
    toolboxes.
  * `dsolve` supports arrays of initial conditions.
  * Fixes for SymPy 1.6 and later.
  * Fixes for Octave 6.x and Octave 7.1.
  * Drop Python 2 support.
  * Update minimum versions of SymPy to 1.4 and Octave to 5.1.
  * Remove deprecated `evalpy` and `python_cmd` utilities.
- Update required versions of dependencies python3-sympy and
  octave in keeping with upstream.
* Thu May  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.9.0:
  * Default python interpreter is now `python3`.
  * Fixes for SymPy 1.5.
    + `@sym/round` changed to round-to-even.
    + fix broken EmptySet `finiteset()`.
  * Documentation updates for upcoming Octave 6.
  * If the Pythonic package is loaded, automatically use it for
    Python communication (see `help sympref` for details).
  * Deprecation notice: `python_cmd` will be removed in a future
    release.
- Switch to python3, drop python*-devel build dependency
* Tue Jul 16 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.0:
  * New symbolic commands: eval ezmesh find sinc
  * Update minimum versions of SymPy to 1.2 and Octave to 4.2.
  * Fixes for SymPy 1.4.
  * Newer SymPy versions improve QR and LU on non-square matrices.
  * Support for expressions with min and max such as `min(x, y)`.
  * `subs(f)` now works: it finds values from the workspace.
  * `gammainc` now regularized correctly.
  * `lambertw` has more consistent printing.
  * Other bug fixes and documentation updates.
- Update version numbers for python-sympy and octave-cli for
  Requires and BuildRequires in keeping with upstream.
* Wed Nov 21 2018 badshah400@gmail.com
- Update to version 2.7.1:
  * New symbolic command: numdem
  * Fixes for SymPy 1.3.
  * Various bug fixes and documentation updates.
* Thu Aug 16 2018 badshah400@gmail.com
- Update to version 2.7.0:
  * New symbolic commands: arg, euler, ezcontour
  * New `@double` numerical functions; these are wrappers around
    SymPy, so they are slower than native floating-point
    implementations: bernoulli, euler, chebyshevT, pochhammer,
    chebyshevU.
  * The initial startup is much quieter!
  * `vpa` now warns of low-precision on non-numbers strings with
    decimals such as `vpa('cos(0.1)')`. See "help vpa" for
    details.
  * `subs` allows multiple scalar variables to be replaced with
    symbolic matrix expressions.
  * symfun can be evaluated at symbolic matrices: `f(sym([1 2; 3
    4]))` now works where `f(x)` is a symfun.
  * Fixes for symfuns such as `syms N(t)` where the function name
    conflicts with a SymPy command.
  * Fixes for how assumptions interact with symfuns.
  * New command `sympref diagnose` to help debug Python/SymPy
    issues.
  * Improve `function_handle` support by supporting more
    functions.
  * Fixes for several bugs mentioning "immutable matrices".
  * `bernoulli` now works with array inputs.
  * Added a `private/defaultpython.m` to make it easier for
    distributors to control which python interpreter is used by
    default.
  * Fixes for GNU Octave 4.4.
  * Fixes for SymPy 1.2.
  * Various bug fixes and documentation updates.
* Fri Aug 18 2017 badshah400@gmail.com
- Update to version 2.6.0
  * New symbolic commands: ellipke, ellipticCE, ellipticCK,
    ellipticCPi, ellipticE, ellipticF, ellipticK, ellipticPi,
    harmonic, kroneckerDelta, pochhammer
  * New `@double` numerical functions; these are wrappers around
    SymPy, so they are slower than native floating-point
    implementations: harmonic.
  * Support for the new SymPy 1.1.1.
  * `solve` now supports vectors of equations and vectors of
    variables.
  * Better warning for `sym(0.1)`, updated docs about floating
    point.
  * Double values can now be converted to their exact rational
    value using `sym(0.1, 'f')`.  Passing `'r'` gives the current
    heuristic behaviour.  Neither raises a warning.
  * The default floating-point heuristics now check for square
    roots of integers, so `sym(sqrt(2))` should work.
  * `sym('i')` and `sym('I')` no longer create the imaginary unit:
    use `sym(i)` or `sym(1i)`.
  * `sym(e)` now gives the same as `exp(sym(1))`.  However,
    `sym('e')` and `syms e` continue to create a variable named
    `e`.
  * `sym` now accepts function handles such as anonymous functions
    as inputs.
  * `subs` is not approriate for numerical evaluation; add an
    example in `help subs` which shows how to do this with
    `function_handle`.
  * Calling `sym(cell)` now creates a sym array instead of a cell
    array. Old behaviour of creating a cell array was deprecated
    in 2.5.0.
  * Bug fix: isequal(n) for symfun's correctly tests the argnames.
* Tue Jun  7 2016 dmitry_r@opensuse.org
- Update to version 2.4.0
  * New symbolic commands:
    acsc, csch, gammaln, polylog, asec, dilog, hypergeom, psi,
    asech, ei, hypot, resize, besseljn, expint, igamma, sech,
    besselyn, ezsurf, jordan, signIm, cat, fresnelc, laguerreL,
    sinint, cosint, fresnels, lgamma, sinhint, coshint, gammainc,
    logint, ssinint
  * Move some functions from the "specfun" package:
    dirac, heaviside, laguerreL, lambertw
  * Re-implement @double/laguerreL for numerical stability.
  * Add spherical Bessel functions: these are called `besseljn` and
    `besselyn`.
* Wed Dec 23 2015 dmitry_r@opensuse.org
- Update to version 2.2.4
  * Bigfix release
* Fri Nov 27 2015 dmitry_r@opensuse.org
- Update to version 2.2.3
  * Bigfix release
* Tue Jul  7 2015 dmitry_r@opensuse.org
- Update to version 2.2.2
  * Bigfix release
* Tue Apr 28 2015 dmitry_r@opensuse.org
- Update to version 2.2.1
  * Fix an ascii pretty printing regression (issue #234).
  * Other minor fixes for doctests, sympref and symreplace.
* Wed Apr 22 2015 dmitry_r@opensuse.org
- Update to version 2.2.1
  * New commands:
    catalan eulergamma lambertw
  * Installing symbolic package now check for Python and minimum
    version of SymPy.
  * Installations from Octave-Forge ("pkg install -forge symbolic")
    should now work on Windows (thanks vassbu).  You will need the
    Python and SymPy dependencies.  Or you can use the [bundled
    package](https://github.com/cbm755/octsympy/releases)
  * Added support for Python 3 (still works with Python 2 as well).
  * Documentation improvements especially to assumptions.  Examples
    within documentation can now be tested with doctests, see the
    `octsympy_doctests.m` function.
  * Fix a warning on Octave 4.0.0-rc1 and make tests work properly.
  * Other bug fixes: assumptions; symvar and symbolic matrix powers;
    various display issues.
* Mon Mar  9 2015 dmitry_r@opensuse.org
- Update to version 2.1.0
  * New commands: columns, degree, formula, ismatrix, numden, rows
  * Additional ways of calling symsum, symprod, and subs for better
    compatibility with other symbolic toolboxes.
  * Bug fixes in poly2sym, sym2poly, symfun, prod, horner, coeffs.
  * Documentation improvements.
  * Improvements to "argnames" and "formula" for the dependent
    variables and dependent expression of a symfun.
  * Improvements to assumptions.
  * Improve symbolic sized matrices such as `A = sym('a', [n m])`.
  * Drop python_cmd_string, which has been deprecated since v0.1.1.
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.0.0
